@@ -62,11 +62,12 @@ except ImportError:
 def display_side_by_side(bts):
     html_str = ""
     for bt in bts:
-        styler = bt.logs.style.set_table_attributes(
-            "style='display:inline'"
-        ).set_caption(bt.name)
-        html_str += styler._repr_html_()
-    display_html(html_str, raw=True)
+        #styler = bt.logs.style.set_table_attributes(
+        #    "style='display:inline'"
+        #).set_caption(bt.name)
+        #html_str += styler._repr_html_()
+        pass
+    display_html(bt.logs._repr_html_(), raw=True)
 
 
 class StrategySequence:
@@ -843,8 +844,8 @@ class Backtester:
         self.dates = [d.date() for d in self.dates]
         for date in self.dates:
             self.datetimes += [
-                sched.loc[date]["market_open"],
-                sched.loc[date]["market_close"],
+                sched.loc[date.isoformat()]["market_open"],
+                sched.loc[date.isoformat()]["market_close"],
             ]
 
         if self._has_strategies:
@@ -979,7 +980,7 @@ class Backtester:
         elif bt.event == "close":
             try:
                 bt.i += 1
-                bt.current_date = bt.dates[bt.i // 2]
+                bt.current_date = bt.dates[bt.i // 2].isoformat()
                 bt.event = "open"
             except IndexError:
                 bt.i -= 1
@@ -1206,7 +1207,7 @@ class Backtester:
                         f"{e.symbol} discontinued on {self.current_date}, liquidating at previous day's {self.event} price"
                     )
 
-                    self.current_date = self.dates[(self.i // 2)]
+                    self.current_date = self.dates[(self.i // 2)].isoformat()
 
                     self.portfolio[e.symbol].liquidate()
                     metric(write=True)
@@ -1215,7 +1216,7 @@ class Backtester:
                         self.i += 2
                     if self.event == "open":
                         self.i += 1
-                    self.current_date = self.dates[(self.i // 2)]
+                    self.current_date = self.dates[(self.i // 2)].isoformat()
 
         self._capital = self._available_capital + self.metric["Portfolio Value"][-1]
 
