@@ -10,24 +10,29 @@ class Fee(ABC):
     It returns the total cost and the number of shares aquired for that cost.
     """
 
-    def __call__(self, price: float, capital: float = None, num_shares: int = None):
-        if num_shares is None:
-            shares = self.num_shares(price, capital)
+    def __call__(self, price: float, capital: float = None, nshares: int = None):
+        if nshares is None:
+            shares = self.nshares(price, capital)
         else:
-            shares = num_shares
+            shares = nshares
         cost = self.cost(price, shares)
+        fee = cost - (price * shares)
         if cost > capital:
             raise InsufficientCapitalError(
                 f"Tried to buy {shares} shares at {price} with only {capital}."
             )
-        return shares, cost
+        return {
+            "nshares": shares,
+            "total": cost,
+            "fee": fee,
+        }
 
     @abstractmethod
-    def num_shares(self, price, capital):
+    def nshares(self, price, capital):
         pass
 
     @abstractmethod
-    def cost(self, price, num_shares):
+    def cost(self, price, nshares):
         pass
 
 
@@ -35,22 +40,22 @@ class FlatPerTrade(Fee):
     def __init__(self, fee):
         self.fee = fee
 
-    def num_shares(self, price, capital):
+    def nshares(self, price, capital):
         return (capital - self.fee) // price
 
-    def cost(self, price, num_shares):
-        return price * num_shares + self.fee
+    def cost(self, price, nshares):
+        return price * nshares + self.fee
 
 
 class FlatPerShare(Fee):
     def __init__(self, fee):
         self.fee = fee
 
-    def num_shares(self, price, capital):
+    def nshares(self, price, capital):
         return capital // (self.fee + price)
 
-    def cost(self, price, num_shares):
-        return (price + self.fee) * num_shares
+    def cost(self, price, nshares):
+        return (price + self.fee) * nshares
 
 
 class NoFee(Fee):
@@ -66,8 +71,8 @@ class NoFee(Fee):
             41, 410
     """
 
-    def num_shares(self, price, capital):
+    def nshares(self, price, capital):
         return capital // price
 
-    def cost(self, price, num_shares):
-        return price * num_shares
+    def cost(self, price, nshares):
+        return price * nshares
